#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.7
visibility:           public
id:                   kan-extensions-5.2.7-L0ZCvS447pRLCnrkDoGpjw
key:                  kan-extensions-5.2.7-L0ZCvS447pRLCnrkDoGpjw
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  5aa8a645f915146a871d20856c55bc86
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.7-L0ZCvS447pRLCnrkDoGpjw
depends:
    adjunctions-4.4.4-HcSYsT8S1Qv7qLF73pNbbu array-0.5.6.0
    base-4.18.2.1 comonad-5.0.9-1SlrkjN0ZqRKKhAWtB7vbo containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    distributive-0.6.2.1-Cpe8IWChck2JiewHveyuC7
    free-5.2-5GWsA6PBRujGOOZGCAfzyR
    invariant-0.6.4-G4jV86xabku8sOlzt0M712 mtl-2.3.1
    profunctors-5.6.3-K9oARcDE2iR8LI35Bou3vl
    semigroupoids-6.0.2-KjN8okTTJFX21iduCaon9n
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

